@@ -2,8 +2,7 @@ from Microsoft.Finance.DataStandards.UnitTest.TestCase.CommonTestCase import Com
 from Microsoft.Finance.DataStandards.UnitTest.TestCase.DimensionTestCase import DimensionTestCase
 from Microsoft.Finance.DataStandards.UnitTest.TestSuite.BaseTestSuite import BaseTestSuite
 from pyspark.sql.session import SparkSession
-
-from unittest import TestLoader, TestSuite
+from unittest import TestLoader
 
 class DimensionTestSuite(BaseTestSuite):
 
