@@ -18,9 +18,9 @@ class FactTestSuite(BaseTestSuite):
         names = loader.getTestCaseNames(FactTestCase)
 
         for name in names:
-            self.TestSuite.addTest(FactTestCase(self.SparkUtility, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregation))
+            self.TestSuite.addTest(FactTestCase(self.SparkUtility, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregation, name))
 
         names = loader.getTestCaseNames(CommonTestCase)
 
         for name in names:
-            self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents))
+            self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents, name))
